@@ -152,6 +152,8 @@ class SlapPipe:
         query = self.conditionally_add_option(options, query, 'regex', 'queryIsRegex')
         query = self.conditionally_add_option(options, query, 'queryisclantag', 'queryIsClanTag')
         query = self.conditionally_add_option(options, query, 'clantag', 'queryIsClanTag')
+        query = self.conditionally_add_option(options, query, 'queryisteamtag', 'queryIsClanTag')
+        query = self.conditionally_add_option(options, query, 'teamtag', 'queryIsClanTag')
         query = self.conditionally_add_option(options, query, 'team', 'queryIsTeam')
         query = self.conditionally_add_option(options, query, 'player', 'queryIsPlayer')
         query, has_limit_option = self.conditionally_add_limit(options, query)
@@ -181,7 +183,7 @@ class SlapPipe:
 
     @staticmethod
     def conditionally_add_option(options, query: str, typed_option_no_delimit: str, query_option_to_add: str) -> str:
-        reg = re.compile(r"(--|–|—)" + typed_option_no_delimit, re.IGNORECASE)
+        reg = re.compile(r"(--|–|—)" + typed_option_no_delimit + r"(\s|$)", re.IGNORECASE)
         (query, n) = reg.subn('', query)
         if n:
             options.add("--" + query_option_to_add)
